Class: HTTParty::Parser Abstract

Inherits:
Object
  • Object
show all
Defined in:
lib/httparty/parser.rb

Overview

This class is abstract.

Read the Custom Parsers section for more information.

The default parser used by HTTParty, supports xml, json, html, yaml, and plain text.

Custom Parsers

If you'd like to do your own custom parsing, subclassing HTTParty::Parser will make that process much easier. There are a few different ways you can utilize HTTParty::Parser as a superclass.

Examples:

Intercept the parsing for all formats

class SimpleParser < HTTParty::Parser
  def parse
    perform_parsing
  end
end

Add the atom format and parsing method to the default parser

class AtomParsingIncluded < HTTParty::Parser
  SupportedFormats.merge!(
    {"application/atom+xml" => :atom}
  )

  def atom
    perform_atom_parsing
  end
end

Only support the atom format

class ParseOnlyAtom < HTTParty::Parser
  SupportedFormats = {"application/atom+xml" => :atom}

  def atom
    perform_atom_parsing
  end
end

Constant Summary collapse

SupportedFormats =
{
  'text/xml'               => :xml,
  'application/xml'        => :xml,
  'application/json'       => :json,
  'text/json'              => :json,
  'application/javascript' => :json,
  'text/javascript'        => :json,
  'text/html'              => :html,
  'application/x-yaml'     => :yaml,
  'text/yaml'              => :yaml,
  'text/plain'             => :plain
}

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(body, format) ⇒ Parser



91
92
93
94
# File 'lib/httparty/parser.rb', line 91

def initialize(body, format)
  @body = body
  @format = format
end

Instance Attribute Details

#bodyString (readonly)

The response body of the request



55
56
57
# File 'lib/httparty/parser.rb', line 55

def body
  @body
end

#formatSymbol (readonly)

The intended parsing format for the request



59
60
61
# File 'lib/httparty/parser.rb', line 59

def format
  @format
end

Class Method Details

.call(body, format) ⇒ Object



64
65
66
# File 'lib/httparty/parser.rb', line 64

def self.call(body, format)
  new(body, format).parse
end

.format_from_mimetype(mimetype) ⇒ Symbol?



76
77
78
# File 'lib/httparty/parser.rb', line 76

def self.format_from_mimetype(mimetype)
  formats[formats.keys.detect {|k| mimetype.include?(k)}]
end

.formatsHash



69
70
71
# File 'lib/httparty/parser.rb', line 69

def self.formats
  const_get(:SupportedFormats)
end

.supported_formatsArray<Symbol>



81
82
83
# File 'lib/httparty/parser.rb', line 81

def self.supported_formats
  formats.values.uniq
end

.supports_format?(format) ⇒ Boolean



87
88
89
# File 'lib/httparty/parser.rb', line 87

def self.supports_format?(format)
  supported_formats.include?(format)
end

Instance Method Details

#parseObject?



99
100
101
102
103
104
105
106
# File 'lib/httparty/parser.rb', line 99

def parse
  return nil if body.nil? || body.empty?
  if supports_format?
    parse_supported_format
  else
    body
  end
end